@@ -1,3 +1,7 @@
+'''Manager class and mixin.
+
+Provides `Manager` class for interacting with a database session via SQLAlchemy's orm.scoped_session.
+'''
 
 from sqlalchemy import engine_from_config, orm
 from sqlalchemy.orm.exc import UnmappedError
@@ -5,11 +9,11 @@ from sqlalchemy.orm.exc import UnmappedError
 from alchy import query, model
 
 
-class ManagerBase(object):
-    '''Useful extensions to self.session'''
+class ManagerMixin(object):
+    '''Useful extensions to self.session.'''
 
     def add(self, *instances):
-        '''Override `session.add()` so it can function like `session.add_all()` and support chaining'''
+        '''Override `session.add()` so it can function like `session.add_all()` and support chaining.'''
         for instance in instances:
             if isinstance(instance, list):
                 self.add(*instance)
@@ -18,11 +22,11 @@ class ManagerBase(object):
         return self.session
 
     def add_commit(self, *instances):
-        '''Add instances to session and commit in one call'''
+        '''Add instances to session and commit in one call.'''
         self.add(*instances).commit()
 
     def delete(self, *instances):
-        '''Override `session.delete()` so it can function like `session.add_all()` and support chaining'''
+        '''Override `session.delete()` so it can function like `session.add_all()` and support chaining.'''
         for instance in instances:
             if isinstance(instance, list):
                 self.delete(*instance)
@@ -31,14 +35,13 @@ class ManagerBase(object):
         return self.session
 
     def delete_commit(self, *instances):
-        '''Delete instances to session and commit in one call'''
+        '''Delete instances to session and commit in one call.'''
         self.delete(*instances).commit()
 
 
-class Manager(ManagerBase):
-    '''
-    Manager for session
-    '''
+class Manager(ManagerMixin):
+    '''Manager for session.'''
+
     def __init__(self, config, Model=None, engine_config_prefix=''):
         self.Model = model.make_declarative_base() if Model is None else Model
         self.config = config
@@ -61,26 +64,21 @@ class Manager(ManagerBase):
 
     @property
     def metadata(self):
+        '''Return `Model`'s metadata object.'''
         return getattr(self.Model, 'metadata', None)
 
     def create_all(self):
-        '''
-        Creates database schema from models
-        '''
+        '''Create database schema from models.'''
         if self.metadata is None:
             raise UnmappedError('Missing declarative base model')
         self.metadata.create_all(bind=self.engine)
 
     def drop_all(self):
-        '''
-        Drops tables defined by models
-        '''
+        '''Drop tables defined by models.'''
         if self.metadata is None:
             raise UnmappedError('Missing declarative base model')
         self.metadata.drop_all(bind=self.engine)
 
     def __getattr__(self, attr):
-        '''
-        Delegate all other attributes to self.session
-        '''
+        '''Delegate all other attributes to self.session.'''
         return getattr(self.session, attr)
